﻿//===============================================================================
// Microsoft patterns & practices
// Guidance on Building a Release Pipeline with Team Foundation Server
//===============================================================================
// Copyright © Microsoft Corporation.  All rights reserved.
// This code released under the terms of the 
// Microsoft patterns & practices license (http://dataguidance.codeplex.com/license)
//===============================================================================


namespace TreyResearch.WcfService.Tests
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using Microsoft.VisualStudio.TestTools.UnitTesting;
    using TreyResearch.WcfService;
    using TreyResearch.WcfService.Store;

    [TestClass]
    public class TheSensorReadingServiceTest
    {
        [TestMethod]
        [TestCategory("Commit Stage")]
        public void When_readings_requested_for_a_client_service_should_return_client_specific_data()
        {
            var clientStore = new InMemoryStore();
            var service = new SensorReadingService();

            // Generate 2 even readings for the first client and store in service
            var firstClientId = Guid.NewGuid().ToString();
            var readingsOne = TestHarness.GenerateAndStoreReadings(clientStore, 2, i => (i + 1) * 2, firstClientId);
            service.StoreSensorReadings(readingsOne);

            // Generate 3 odd readings for the second client and store in service
            var secondClientId = Guid.NewGuid().ToString();
            var readingsTwo = TestHarness.GenerateAndStoreReadings(clientStore, 2, i => (2 * i) + 1, secondClientId);
            service.StoreSensorReadings(readingsTwo);

            Assert.AreEqual(service.GetSensorReadings(firstClientId).TotalCount, 2);
            CollectionAssert.AreEqual(readingsOne.ToList(), service.GetSensorReadings(firstClientId).Results.ToList(), Comparer<SensorReading>.Create((x, y) => x.Id.CompareTo(y.Id)));
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentNullException))]
        [TestCategory("Commit Stage")]
        public void When_trying_to_store_a_null_reading_service_should_throw_exception()
        {
            var service = new SensorReadingService();
            service.StoreSensorReading(null);
        }
    }
}
