﻿//===============================================================================
// Microsoft patterns & practices
// Guidance on Building a Release Pipeline with Team Foundation Server
//===============================================================================
// Copyright © Microsoft Corporation.  All rights reserved.
// This code released under the terms of the 
// Microsoft patterns & practices license (http://dataguidance.codeplex.com/license)
//===============================================================================


namespace TreyResearch.WcfService
{
    using System;
    using System.Collections.Generic;
    using TreyResearch.WcfService.Store;

    public class SensorReadingService : ISensorReadingService
    {
        private static readonly IDictionary<string, ISensorReadingStore> _storesByUser = new Dictionary<string, ISensorReadingStore>();

        public ResultPage<SensorReading> GetSensorReadingsPage(string clientId, int pageNumber)
        {
            return GetStoreForUserId(clientId).Get(pageNumber);
        }

        public ResultPage<SensorReading> GetSensorReadings(string clientId)
        {
            return GetSensorReadingsPage(clientId, 1);
        }

        public void StoreSensorReading(SensorReading reading)
        {
            if (reading == null) throw new ArgumentNullException("reading");
            var store = GetStoreForUserId(reading.ClientId);
            store.Save(reading);
        }

        public void StoreSensorReadings(IEnumerable<SensorReading> sensorReadings)
        {
            foreach (var sensorReading in sensorReadings)
            {
                this.StoreSensorReading(sensorReading);
            }
        }

        private ISensorReadingStore GetStoreForUserId(string clientId)
        {
            if (!_storesByUser.ContainsKey(clientId)) _storesByUser[clientId] = new InMemoryStore();
            return _storesByUser[clientId];
        }
    }
}
