﻿//===============================================================================
// Microsoft patterns & practices
// Guidance on Building a Release Pipeline with Team Foundation Server
//===============================================================================
// Copyright © Microsoft Corporation.  All rights reserved.
// This code released under the terms of the 
// Microsoft patterns & practices license (http://dataguidance.codeplex.com/license)
//===============================================================================


namespace TreyResearch.WcfService.Store
{
    using System.Collections.Generic;
    using System.Linq;

    public class InMemoryStore : ISensorReadingStore
    {
        public const int PageSize = 5;

        // TODO: Static added in order to maintain state between requests. Research a better way.
        private readonly ICollection<SensorReading> _internalStore = new List<SensorReading>();

        public void Save(SensorReading reading)
        {
            // simulate serialization of data by creating a new instance
            _internalStore.Add(new SensorReading
                {
                    Id = reading.Id,
                    CreateDate = reading.CreateDate
                });
        }

        public ResultPage<SensorReading> Get(int pageNumber)
        {
            var skipCount = (pageNumber - 1) * PageSize;
            return new ResultPage<SensorReading>
                {
                    TotalCount = _internalStore.Count(),
                    PageNumber = pageNumber,
                    Results = _internalStore.Skip(skipCount).Take(PageSize)
                };
        }

        public ResultPage<SensorReading> Get()
        {
            return Get(1);
        }
    }
}