SELECT
	-- We are adding a trailing '0' for 1-digit week numbers,
	-- so we use the RIGHT function to remove it if was not
	-- needed because the week number had 2 digits.
	RIGHT
	(
		'0'
		-- Number of the week inside the year
		+ CAST(DATEPART(wk, [CurrentBug].[Date])
			AS VARCHAR)
		-- Separator
		+ '/'
		-- Year
		+ CAST(DATEPART(yyyy, [CurrentBug].[Date])
			AS VARCHAR)
		-- Maximum length of the returned value (format: WW/YYYY)
		, 7
	) AS [Week]
	-- Mean Time Between Failures, in hours, per each week
	,AVG(
		DATEDIFF(hh, [FormerBug].[Date], [CurrentBug].[Date])
		) AS [MTBF in hours]
FROM
(
	-- List of bugs, ordered by Activated date
	SELECT
		(
			ROW_NUMBER()
			OVER(ORDER BY [Microsoft_VSTS_Common_ActivatedDate] ASC)
		) + 1 AS [ID]
		,[Microsoft_VSTS_Common_ActivatedDate] AS [Date]
	FROM [dbo].[CurrentWorkItemView]
	WHERE
		[ProjectPath] = '\DefaultCollection\Iteration 3'
		AND [System_WorkItemType] = 'Bug'
		AND [System_State] = 'Closed'
) AS [FormerBug]
INNER JOIN
(
	-- Just the same list of bugs as before, also ordered by Activated
	-- date, but with the rows shifted one position so we can
	-- calculate the time between one bug and the next one (notice
	-- that in this case the result of the ROW_NUMBER function is not
	-- increased by 1 to make the shift happen)
	SELECT
		(
			ROW_NUMBER()
			OVER(ORDER BY [Microsoft_VSTS_Common_ActivatedDate] ASC)
		) AS [ID]
		,[Microsoft_VSTS_Common_ActivatedDate] AS [Date]
	FROM [dbo].[CurrentWorkItemView]
	WHERE
		[ProjectPath] = '\DefaultCollection\Iteration 3'
		AND [System_WorkItemType] = 'Bug'
		AND [System_State] = 'Closed'
) AS [CurrentBug]
ON [FormerBug].[ID] = [CurrentBug].[ID]
GROUP BY
	-- Grouping by week and year to calculate the average
	DATEPART(wk, [CurrentBug].[Date])
	,DATEPART(yyyy, [CurrentBug].[Date])
