﻿//===============================================================================
// Microsoft patterns & practices
// Guidance on Building a Release Pipeline with Team Foundation Server
//===============================================================================
// Copyright © Microsoft Corporation.  All rights reserved.
// This code released under the terms of the 
// Microsoft patterns & practices license (http://dataguidance.codeplex.com/license)
//===============================================================================


namespace TreyResearch.WcfService.Tests
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using Microsoft.VisualStudio.TestTools.UnitTesting;

    using TreyResearch.WcfService;
    using TreyResearch.WcfService.Store;

    [TestClass]
    public class TheInMemoryStoreTest
    {
        [TestMethod]
        public void When_saving_items_should_return_a_faithful_representation_of_the_items()
        {
            var store = new InMemoryStore();
            var readings = TestHarness.GenerateAndStoreReadings(store, 3, i => i + 1);
            var results = store.Get().Results.ToList();
            
            // We compare the ids because cannot assume that the instances
            // themselves are the same. They might have been serialized
            // and deserialized before being returned to us.
            CollectionAssert.AreEqual(readings.ToArray(), results, Comparer<SensorReading>.Create((x, y) => x.Id.CompareTo(y.Id)));
        }

        [TestMethod]
        public void When_a_2nd_page_is_requested_should_return_the_2nd_page_of_results()
        {
            var store = new InMemoryStore();
            const int twoPages = 2*InMemoryStore.PageSize;

            for (int i = 0; i < twoPages; i++)
            {
                store.Save(new SensorReading {Id = i, CreateDate = new DateTime(1975, 4, 1)});
            }

            var page = store.Get(2);
            Assert.AreEqual(InMemoryStore.PageSize, page.Results.Count());
            Assert.AreEqual(InMemoryStore.PageSize, page.Results.First().Id);
        }
    }
}
