﻿//===============================================================================
// Microsoft patterns & practices
// Guidance on Building a Release Pipeline with Team Foundation Server
//===============================================================================
// Copyright © Microsoft Corporation.  All rights reserved.
// This code released under the terms of the 
// Microsoft patterns & practices license (http://dataguidance.codeplex.com/license)
//===============================================================================


namespace TreyResearch.WpfClient.CodeUITest
{
    using System;
    using Microsoft.VisualStudio.TestTools.UITesting;
    using Microsoft.VisualStudio.TestTools.UnitTesting;
    using Mouse = Microsoft.VisualStudio.TestTools.UITesting.Mouse;
    using Microsoft.VisualStudio.TestTools.UITesting.WpfControls;
    using System.Configuration;
    using Microsoft.VisualStudio.TestTools.UITest.Extension;
    using System.Drawing;
    using System.Diagnostics;
    using System.IO;
    using System.Linq;


    public partial class UIMap
    {

        /// <summary>
        /// Steps:
        /// 1. Launch client app
        /// </summary>
        public void LaunchTreyResearchWPFClient()
        {
            #region Variable Declarations
            WpfButton uISubmitReadingButton = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIRecordReadingsTabPage.UISubmitReadingButton;
            WpfTabPage uIViewReadingsTabPage = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIViewReadingsTabPage;
            WpfText uIRandomReadingTextBlock = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIRecordReadingsTabPage.UIRandomReadingTextBlock;
            #endregion

            // Launch client app
            string fileName = TreyResearchWpfClientExePath();
            if (fileName == string.Empty)
            {
                Assert.Fail("Do not find TreyResearch.WpfClient.exe!");
            }
            System.Diagnostics.Process.Start(fileName);

        }

        /// <summary>
        /// Verify:
        /// 1. Submit Reading button appears
        /// 2. Submit Reading button enabled
        /// 3. Random reading displayed        
        /// </summary>
        public void VerifyInitalPage()
        {
            #region Variable Declarations
            WpfButton uISubmitReadingButton = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIRecordReadingsTabPage.UISubmitReadingButton;
            WpfText uIRandomReadingTextBlock = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIRecordReadingsTabPage.UIRandomReadingTextBlock;
            int iRandomReading = Convert.ToInt32(uIRandomReadingTextBlock.DisplayText);

            #endregion

            // Verify that the 'DisplayText' property of 'Submit Reading' button equals 'Submit Reading'
            Assert.AreEqual(this.AssertMethod1ExpectedValues.UISubmitReadingButtonDisplayText, uISubmitReadingButton.DisplayText);
            Assert.IsTrue(uISubmitReadingButton.Enabled);
            Assert.IsTrue(iRandomReading > 0 && iRandomReading < 10000);

        }

        /// <summary>
        /// Steps:
        /// 1. Launch client app
        /// 
        /// Verify:
        /// 1. Current reading is diffrent as initial reading
        /// </summary>
        public void SwichedTabPage()
        {
            #region Variable Declarations
            WpfTabPage uIViewReadingsTabPage = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIViewReadingsTabPage;
            WpfTabPage uIRecordReadingsTabPage = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIRecordReadingsTabPage;
            WpfText uIRandomReadingTextBlock = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList.UIRecordReadingsTabPage.UIRandomReadingTextBlock;
            #endregion

            // Launch client app
            string fileName = TreyResearchWpfClientExePath();
            if (fileName == string.Empty)
            {
                Assert.Fail("Do not find TreyResearch.WpfClient.exe!");
            }
            System.Diagnostics.Process.Start(fileName);

            // Record the initial reading
            string initialReading = uIRandomReadingTextBlock.DisplayText;

            // Click 'View Readings' tab
            Mouse.Click(uIViewReadingsTabPage, new System.Drawing.Point(33, 7));

            // Click 'Record Readings' tab
            Mouse.Click(uIRecordReadingsTabPage, new System.Drawing.Point(10, 7));

            // Get the current reading
            string currentReading = uIRandomReadingTextBlock.DisplayText;

            // Verify if reading changed
            Assert.AreNotEqual(initialReading, currentReading);

        }

        /// <summary>
        /// This is a test method for complex UI automation debugging
        /// </summary>
        public void RecordedMethod2()
        {
            // Launch client app
            string fileName = TreyResearchWpfClientExePath();
            if (fileName == string.Empty)
            {
                Assert.Fail("Do not find TreyResearch.WpfClient.exe!");
            }
            System.Diagnostics.Process.Start(fileName);

            #region Variable Declarations

            var uISensorReadingTabsConTabList = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList;
            var uIViewReadingsTabPage = uISensorReadingTabsConTabList.UIViewReadingsTabPage;
            var uIRecordReadingsTabPage = uISensorReadingTabsConTabList.UIRecordReadingsTabPage;
            var uISubmitReadingButton = uIRecordReadingsTabPage.UISubmitReadingButton;
            var uINextButton = uIViewReadingsTabPage.UINextButton;
            var uISubmitRandomReading = uIRecordReadingsTabPage.UIRandomReadingTextBlock;
            #endregion

            //Submit Random Number
            uISensorReadingTabsConTabList.SelectedIndex = 0;
            var txtForCheck = uISubmitRandomReading.DisplayText;
            for (int i = 0; i < 10; i++)
            {
                txtForCheck = uISubmitRandomReading.DisplayText;
                Mouse.Click(uISubmitReadingButton, new Point(37, 15));
            }

            //Change the ViewReadingsTabPage
            bool isTabControlOk = false;
            Mouse.Move(new Point(100, 100));
            while (!isTabControlOk)
            {
                uISensorReadingTabsConTabList.SelectedIndex = 1;
                isTabControlOk = uISensorReadingTabsConTabList.SelectedIndex == 1;
            }

            //Wait until Next button available
            var isNextExist = false;
            while (!isNextExist)
            {
                Mouse.Move(new Point(100, 100));
                isNextExist = uINextButton.WaitForControlExist();
            }

            //Click Next button to the last page
            var isNextButtonEnable = true;
            while (isNextButtonEnable)
            {
                try
                {
                    isNextButtonEnable = uINextButton.Enabled;
                    Mouse.Click(uINextButton, new Point(12, 12));
                }
                catch (UITestControlNotAvailableException ee)
                {
                    if (ee.HResult == -268111872)
                    {
                        Mouse.Move(new Point(100, 100));
                        continue;
                    }
                }
            }

            // If the random num match the result
            var txtResult = new WpfText(uIViewReadingsTabPage);
            txtResult.SearchProperties[WpfText.PropertyNames.AutomationId] = txtForCheck;
            var ok = txtResult.TryFind();
            if (ok)
            {
                Debug.WriteLine("Found Text---" + txtForCheck + "---" + DateTime.Now);

            }
            else
            {
                Debug.WriteLine("Failed!!!---" + txtForCheck);
            }

            //RecordedMethod2();
        }

        /// <summary>
        /// Steps:
        /// 1. Launch client app
        /// 2. Find Submit button and click 5 times
        /// 3. Go to View Readings tab
        /// 4. Find the number and paging info text
        /// 
        /// Verify:
        /// 1. Total number of readings >= 5
        /// </summary>
        public void SubmitFiveReadings()
        {
            #region Variable Declarations
            var uISensorReadingTabsConTabList = this.UISENSORREADINGSWindow.UISensorReadingTabsConTabList;
            var uIViewReadingsTabPage = uISensorReadingTabsConTabList.UIViewReadingsTabPage;
            var uIRecordReadingsTabPage = uISensorReadingTabsConTabList.UIRecordReadingsTabPage;
            var uISubmitReadingButton = uIRecordReadingsTabPage.UISubmitReadingButton;
            var uIPageInfo = uIViewReadingsTabPage.UIPageInfo;
            #endregion

            // Launch client app
            string fileName = TreyResearchWpfClientExePath();
            if (fileName == string.Empty)
            {
                Assert.Fail("Do not find TreyResearch.WpfClient.exe!");
            }
            System.Diagnostics.Process.Start(fileName);

            // Click Submit Reading button 5 times
            uIRecordReadingsTabPage.SetFocus();
            for (int i = 0; i < 5; i++)
            {
                Mouse.Click(uISubmitReadingButton, new Point(37, 15));
            }

            // Go to View Readings tab
            uIViewReadingsTabPage.SetFocus();
            Mouse.Move(new Point(100, 100));

            // Find the paging info text like "Total: 5 Showing Page 1 of 1" and parse the number
            var result = uIPageInfo.DisplayText.Split(':', 'S')[1];
            var resultNum = 0;
            int.TryParse(result.TrimStart().TrimEnd(), out resultNum);

            // Verify if number of readings >= 5
            Assert.IsTrue(resultNum >= 5);

        }

        /// <summary>
        /// Find TreyResearch.WpfClient.exe path.
        /// </summary>
        /// <returns></returns>
        private string TreyResearchWpfClientExePath()
        {
            return ConfigurationManager.AppSettings["WpfClientExecutable"].ToString();
        }


        #region Fields
        private AssertMethod1ExpectedValues mAssertMethod1ExpectedValues;
        private UISENSORREADINGSWindow mUISENSORREADINGSWindow;

        #endregion

        #region Properties
        public virtual AssertMethod1ExpectedValues AssertMethod1ExpectedValues
        {
            get
            {
                if ((this.mAssertMethod1ExpectedValues == null))
                {
                    this.mAssertMethod1ExpectedValues = new AssertMethod1ExpectedValues();
                }
                return this.mAssertMethod1ExpectedValues;
            }
        }
        public UISENSORREADINGSWindow UISENSORREADINGSWindow
        {
            get
            {
                if ((this.mUISENSORREADINGSWindow == null))
                {
                    this.mUISENSORREADINGSWindow = new UISENSORREADINGSWindow();
                }
                return this.mUISENSORREADINGSWindow;
            }
        }
        #endregion
    }

    public class UIRecordReadingsTabPage : WpfTabPage
    {

        public UIRecordReadingsTabPage(UITestControl searchLimitContainer) :
            base(searchLimitContainer)
        {
            #region Search Criteria
            this.SearchProperties[WpfTabPage.PropertyNames.AutomationId] = "RecordReadingsPage";
            this.WindowTitles.Add("SENSOR READINGS");
            #endregion
        }

        #region Properties
        public WpfButton UISubmitReadingButton
        {
            get
            {
                if ((this.mUISubmitReadingButton == null))
                {
                    this.mUISubmitReadingButton = new WpfButton(this);
                    #region Search Criteria
                    this.mUISubmitReadingButton.SearchProperties[WpfButton.PropertyNames.Name] = "Submit Reading";


                    this.mUISubmitReadingButton.WindowTitles.Add("SENSOR READINGS");
                    #endregion
                }
                return this.mUISubmitReadingButton;
            }
        }

        public WpfText UIRandomReadingTextBlock
        {
            get
            {
                if (mUIRandomReadingTextBlock == null)
                {
                    this.mUIRandomReadingTextBlock = new WpfText(this);
                    #region Search Criteria
                    this.mUIRandomReadingTextBlock.SearchProperties[WpfText.PropertyNames.AutomationId] = "RandomReading";
                    this.mUIRandomReadingTextBlock.WindowTitles.Add("SENSOR READINGS");
                    #endregion
                }
                return mUIRandomReadingTextBlock;
            }
        }

        #endregion

        #region Fields
        private WpfButton mUISubmitReadingButton;
        private WpfText mUIRandomReadingTextBlock;

        #endregion
    }

    public class UIViewReadingsTabPage : WpfTabPage
    {

        public UIViewReadingsTabPage(UITestControl searchLimitContainer) :
            base(searchLimitContainer)
        {
            #region Search Criteria
            this.SearchProperties[WpfTabPage.PropertyNames.AutomationId] = "GetReadingsPage";
            this.WindowTitles.Add("SENSOR READINGS");
            #endregion
        }

        #region Properties
        public WpfText UIItemText
        {
            get
            {
                if ((this.mUIItemText == null))
                {
                    this.mUIItemText = new WpfText(this);
                    #region Search Criteria
                    this.mUIItemText.SearchProperties[WpfText.PropertyNames.AutomationId] = "TextBlock";
                    this.mUIItemText.WindowTitles.Add("SENSOR READINGS");
                    #endregion
                }
                return this.mUIItemText;
            }
        }
        public WpfButton UINextButton
        {
            get
            {
                if ((this.mUINextButton == null))
                {
                    this.mUINextButton = new WpfButton(this);
                    #region Search Criteria
                    this.mUINextButton.SearchProperties[WpfButton.PropertyNames.AutomationId] = "Next";
                    this.mUINextButton.WindowTitles.Add("SENSOR READINGS");
                    #endregion
                }
                return this.mUINextButton;
            }
        }

        public WpfText UIPageInfo
        {
            get
            {
                if (this.mUIPageInfo == null)
                {
                    this.mUIPageInfo = new WpfText(this);

                    #region Search Criteria
                    this.mUIPageInfo.SearchProperties[WpfText.PropertyNames.AutomationId] = "PageInfo";
                    this.mUIPageInfo.WindowTitles.Add("SENSOR READINGS");
                    #endregion
                }

                return this.mUIPageInfo;
            }
        }
        public UITestControlCollection MUITestControlCollection
        {
            get
            {
                WpfText W = new WpfText();
                W.SearchProperties.Add(WpfText.PropertyNames.ClassName, "TextBlock");

                return W.FindMatchingControls();
            }
        }
        #endregion

        #region Fields
        private WpfText mUIItemText;
        private WpfButton mUINextButton;
        //private UITestControlCollection mUITestControlCollection;
        private WpfText mUIPageInfo;

        #endregion
    }

    public class UISENSORREADINGSWindow : WpfWindow
    {

        public UISENSORREADINGSWindow()
        {
            #region Search Criteria
            this.SearchProperties[WpfWindow.PropertyNames.Name] = "SENSOR READINGS";
            this.SearchProperties.Add(new PropertyExpression(WpfWindow.PropertyNames.ClassName, "HwndWrapper", PropertyExpressionOperator.Contains));
            this.WindowTitles.Add("SENSOR READINGS");
            #endregion
        }

        #region Properties
        public UISensorReadingTabsConTabList UISensorReadingTabsConTabList
        {
            get
            {
                if ((this.mUISensorReadingTabsConTabList == null))
                {
                    this.mUISensorReadingTabsConTabList = new UISensorReadingTabsConTabList(this);
                }
                return this.mUISensorReadingTabsConTabList;
            }
        }
        #endregion

        #region Fields
        private UISensorReadingTabsConTabList mUISensorReadingTabsConTabList;
        #endregion
    }

    public class UISensorReadingTabsConTabList : WpfTabList
    {

        public UISensorReadingTabsConTabList(UITestControl searchLimitContainer) :
            base(searchLimitContainer)
        {
            #region Search Criteria
            this.SearchProperties[WpfTabList.PropertyNames.AutomationId] = "SensorReadingTabsContainer";
            this.WindowTitles.Add("SENSOR READINGS");
            #endregion
        }

        #region Properties
        public UIRecordReadingsTabPage UIRecordReadingsTabPage
        {
            get
            {
                if ((this.mUIRecordReadingsTabPage == null))
                {
                    this.mUIRecordReadingsTabPage = new UIRecordReadingsTabPage(this);
                }
                return this.mUIRecordReadingsTabPage;
            }
        }

        public UIViewReadingsTabPage UIViewReadingsTabPage
        {
            get
            {
                if ((this.mUIViewReadingsTabPage == null))
                {
                    this.mUIViewReadingsTabPage = new UIViewReadingsTabPage(this);
                }
                return this.mUIViewReadingsTabPage;
            }
        }
        #endregion

        #region Fields
        private UIRecordReadingsTabPage mUIRecordReadingsTabPage;

        private UIViewReadingsTabPage mUIViewReadingsTabPage;
        #endregion
    }

    /// <summary>
    /// Parameters to be passed into 'AssertMethod1'
    /// </summary>
    public class AssertMethod1ExpectedValues
    {

        #region Fields
        /// <summary>
        /// Verify that the 'DisplayText' property of 'Submit Reading' button equals 'Submit Reading'
        /// </summary>
        public string UISubmitReadingButtonDisplayText = "Submit Reading";
        #endregion
    }

}
